============================================
COBalD -- the Opportunistic Balancing Daemon
============================================

.. image:: https://readthedocs.org/projects/cobald/badge/?version=latest
    :target: http://cobald.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://badges.gitter.im/MatterMiners.png
    :target: https://gitter.im/MatterMiners/community
    :alt: Development and Help Chat

.. image:: https://travis-ci.org/MatterMiners/cobald.svg?branch=master
    :target: https://travis-ci.org/MatterMiners/cobald
    :alt: Test Status

.. image:: https://codecov.io/gh/MatterMiners/cobald/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/MatterMiners/cobald
    :alt: Test Coverage

.. image:: https://img.shields.io/pypi/v/cobald.svg
    :alt: Available on PyPI
    :target: https://pypi.python.org/pypi/cobald/

.. image:: https://img.shields.io/github/license/MatterMiners/cobald.svg
    :alt: License
    :target: https://github.com/MatterMiners/cobald/blob/master/LICENSE

.. image:: https://zenodo.org/badge/129873843.svg
   :alt: Zenodo DOI
   :target: https://zenodo.org/badge/latestdoi/129873843

The ``cobald`` is a lightweight framework to balance opportunistic resources:
cloud bursting, container orchestration, allocation scaling and more.
Its lightweight model for resource control and composition
makes it easy to integrate custom resources and manage them at a large scale.

Getting Started
===============

If you want to use ``cobald``, please refer to the `documentation`_.
This provides information and examples on how to install, configure and run ``cobald``.
It also covers how to extend ``cobald`` with plugins,
and how to integrate ``cobald`` into your own infrastructure.

If you want to contribute to ``cobald``, please refer to our `github`_ repository.
Feel free to open tickets and pull requests.
Note that the ``cobald`` repository houses the generic components only.
There are separate repositories for the various resource backends and plugins.

If you want to get in touch directly, head over to our `gitter`_ channel.

.. _github: https://github.com/MatterMiners/cobald
.. _documentation: http://cobald.readthedocs.io/
.. _gitter: https://gitter.im/MatterMiners/community
